<?php
namespace Teknisa\PLA\Modules\Cardapio\Services;

use Zeedhi\Framework\DataSource\FilterCriteria;
use \Setforms2\Shared\ORM\DateTime;
use \Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use \Zeedhi\Framework\DB\StoredProcedure\Param;

class Pla05900AssistenteCardapioService {

    protected $dataSourceManager;
    protected $environment;
    protected $entityManager;
    protected $crudService;
    protected $authService;

    public function __construct($dataSourceManager, $environment, $entityManager, $crudService, $authService) {
        $this->dataSourceManager = $dataSourceManager;
        $this->environment       = $environment;
        $this->entityManager     = $entityManager;
        $this->crudService       = $crudService;
        $this->authService       = $authService;
    }
    
    public function checkCtrlAprovCard($row) {
        $query = "SELECT
                    SERVICO.CDFILIAL,
                    SERVICO.CDSERVFILI
                FROM
                    SERVICO,
                    CTRLAPROVCARD,
                    CALENCARD
                WHERE
                    CTRLAPROVCARD.CDFILIAL = SERVICO.CDFILIAL AND
                    CTRLAPROVCARD.CDSERVFILI = SERVICO.CDSERVFILI AND
                    CTRLAPROVCARD.CDFILIAL = CALENCARD.CDFILIAL AND
                    CTRLAPROVCARD.DTMESCARDAPROV = CALENCARD.DTMESCALENCARD AND
                    CTRLAPROVCARD.DTAPROCARDMATR IS NULL AND
                    CTRLAPROVCARD.DTAPROCARDFILI IS NULL AND
                    NOT ( CTRLAPROVCARD.DTLIBECARDMATR IS NULL ) AND
                    TRUNC(SYSDATE) <= ( CALENCARD.DTLIMAPROVFILI + NVL(CALENCARD.QTDIAPRORAPROV, 0)) AND
                    CTRLAPROVCARD.CDFILIAL =:CDFILIAL AND
                    CTRLAPROVCARD.CDSERVFILI =:CDSERVFILI AND
                    CTRLAPROVCARD.DTMESCARDAPROV =:DTMESCARDAPIO";
        $params = array(
            "CDFILIAL"   => $row['CDFILIDEST'],
            "CDSERVFILI" => $row['CDSERVDEST'],
            "DTMESCARDAPIO" => $row['DTMESCARDAPIO']
        );
        return $this->entityManager->getConnection()->fetchAll($query, $params);
    }
    
    public function exportaCard($nrlista, $row, $servico) {
        $connection = $this->entityManager->getConnection();
        $procedure = new StoredProcedure($connection, 'EXPORTA_CARDAPIO');
        $procedure->addParam(new Param('P_CDFILIORIG', Param::PARAM_INPUT, $servico['CDFILIAL'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDSERVORIG', Param::PARAM_INPUT, $servico['CDSERVFILI'].'_', Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTINIORIG', Param::PARAM_INPUT, $row['DTORIG']['start'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTFINORIG', Param::PARAM_INPUT, $row['DTORIG']['end'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDFILIDEST', Param::PARAM_INPUT, $servico['CDFILIAL'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDSERVDEST', Param::PARAM_INPUT, $servico['CDSERVFILI'].'_', Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTINIDEST', Param::PARAM_INPUT, $row['DTDESTINI'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTFINDEST', Param::PARAM_INPUT, $row['DTDESTFIN'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CONFIGORIG', Param::PARAM_INPUT, $nrlista.'_', Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_IDCOPCOMENS', Param::PARAM_INPUT, $row['copiarComens'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_IDSOBREPOR', Param::PARAM_INPUT, $row['sobreporExp'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDOPERADOR', Param::PARAM_INPUT, $row['CDOPERADOR'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_MODOPROC', Param::PARAM_INPUT, $row['MODOPROC'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRLOGINTCARD', Param::PARAM_OUTPUT, $nrlogintcard, Param::PARAM_TYPE_STR, 10));
        $nrlogintcard = $procedure->execute();
        return $nrlogintcard;
    }
    
    public function exportaCardMantConf($nrlista, $row, $servico) {
        $connection = $this->entityManager->getConnection();
        $procedure = new StoredProcedure($connection, 'EXPORTA_CARDAPIO_CONFIG');
        $procedure->addParam(new Param('P_CDFILIORIG', Param::PARAM_INPUT, $servico['CDFILIAL'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDSERVORIG', Param::PARAM_INPUT, $servico['CDSERVFILI'].'_', Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTINIORIG', Param::PARAM_INPUT, $row['DTORIG']['start'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTFINORIG', Param::PARAM_INPUT, $row['DTORIG']['end'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDFILIDEST', Param::PARAM_INPUT, $servico['CDFILIAL'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDSERVDEST', Param::PARAM_INPUT, $servico['CDSERVFILI'].'_', Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTINIDEST', Param::PARAM_INPUT, $row['DTDESTINI'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTFINDEST', Param::PARAM_INPUT, $row['DTDESTFIN'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CONFIGORIG', Param::PARAM_INPUT, $nrlista.'_', Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_IDCOPCOMENS', Param::PARAM_INPUT, $row['copiarComens'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_IDSOBREPOR', Param::PARAM_INPUT, $row['sobreporExp'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDOPERADOR', Param::PARAM_INPUT, $row['CDOPERADOR'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_MODOPROC', Param::PARAM_INPUT, $row['MODOPROC'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRLOGINTCARD', Param::PARAM_OUTPUT, $nrlogintcard, Param::PARAM_TYPE_STR, 10));
        $nrlogintcard = $procedure->execute();
        return $nrlogintcard;
    }
    
    public function exportaCardapioCompleta($row, $nrlistaPeriodo, $nrlistaServicos) {
        $nrlogintcard = "";
        $connection = $this->entityManager->getConnection();
        $procedure = new StoredProcedure($connection, 'EXPORTA_CARDAPIO_COMPLETA');
        $procedure->addParam(new Param('P_NRLISTAORIDEST', Param::PARAM_INPUT, $nrlistaServicos, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRLISTAPERIODO', Param::PARAM_INPUT, $nrlistaPeriodo, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_MANTEMCONFIG', Param::PARAM_INPUT, $row['manterConfig'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_IDCOPCOMENS', Param::PARAM_INPUT, $row['copiarComens'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_IDSOBREPOR', Param::PARAM_INPUT, $row['sobreporExp'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDOPERADOR', Param::PARAM_INPUT, $row['CDOPERADOR'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_MODOPROC', Param::PARAM_INPUT, $row['MODOPROC'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRLOGINTCARD', Param::PARAM_OUTPUT, $nrlogintcard, Param::PARAM_TYPE_STR, 10));
        $nrlogintcard = $procedure->execute();
        return $nrlogintcard;
    }
    
    public function getGrupoRevisaoCardapio() {
        $filterCriteria = new FilterCriteria('autgrupop');
        $filterCriteria->addCondition('IDAUTGRUPOP', 'LRCD');
        $dataSet = $this->dataSourceManager->findBy($filterCriteria);
        $rows = $dataSet->getRows();
        return isset($rows[0]) ? $rows[0]['CDGRUPOPER'] : null;
    }
    
    public function getParamFilial($cdfilial) {
        $filterCriteria = new FilterCriteria('paramfilial');
        $filterCriteria->addCondition('CDFILIAL', 'IN', $cdfilial);
        $dataSet = $this->dataSourceManager->findBy($filterCriteria);
        $rows = $dataSet->getRows();
        return $rows;
    }

    public function getParamGeral() {
        $filterCriteria = new FilterCriteria('paramgeral');
        $filterCriteria->addCondition('NRORG', $this->environment->getNrOrg());
        $dataSet = $this->dataSourceManager->findBy($filterCriteria);
        $rows = $dataSet->getRows();
        return $rows[0];
    }
    
    public function getTipoOperador() {
        $row = array(
            'CDOPERADOR'   => $this->environment->getCdOperador(),
            'AUTENTICACAO' => array(
    			'COLUMN_NAME'=> null,
    			'ALIAS_NAME'=> 'LRCD'
		    )
        );
        $permission = $this->authService->returnOperatorInGroup($row);

        return $permission ? 'M' : 'F';

    }
    
    public function insertCnfcamesLista($row, $servico,  $nrlista) {
        $query = "INSERT INTO LISTA
                    (NRLISTA, CDLISTA) 
                        (SELECT 
                            :NRLISTA, LPAD(NRSEQCNFMES, 3, '0')
                        FROM
                            CNFCAMES
                        WHERE
                            CDFILIAL = :CDFILIAL AND
                            CDSERVFILI  = :CDSERVFILI AND
                            DTREFECNFMES = :DTMES)";
        $params = array(
            "NRLISTA" => $nrlista,
            "CDFILIAL"   => $servico['CDFILIORIG'],
            "CDSERVFILI" => $servico['CDSERVORIG'],
            "DTMES" => $row['DTMESCARDAPIOINI']
        );
        $sql = $this->entityManager->getConnection()->prepare($query);
        $sql->execute($params);
    }

    public function retornaDataProcessamento($cdfilial) {
        $dataSet = $this->dataSourceManager->findBy(new FilterCriteria(self::PARAMGERAL));
        $rows = $dataSet->getRows();
        if ($rows[0]['IDUTILDTPROC'] != 'S') {
            $dataProcessamento = date('d/m/Y');
        } else {
            $dataProcessamento = $this->retornaDataProcPorFilial($cdfilial);
        }
        return $dataProcessamento;
    }
}